@@ -3,7 +3,9 @@ function(name="", times=NULL, signal=NULL, report=NULL, plotFile=NULL, dataFile=
 	Nplots = sum(c(!is.null(times) && !is.null(signal), !is.null(report) && !report$error));
 	if(Nplots==0) return();
 	
-	old.par <- par(mfrow=c(1, Nplots))	
+	oldpar = par(no.readonly = TRUE)
+	on.exit(par(oldpar))
+	par(mfrow=c(1, Nplots))	
 	
 	if(!is.null(times) && !is.null(signal)){
 		#plot time series
@@ -22,8 +24,6 @@ function(name="", times=NULL, signal=NULL, report=NULL, plotFile=NULL, dataFile=
 
 	}
 	
-	par(old.par)
-	
 	if(!is.null(plotFile)){
 		#save plot as PDF
 		dir.create(dirname(plotFile), showWarnings=FALSE);
